.. _filters_ref:

Filters
=======


.. automodule:: pyvista.filters


Dataset Filters
---------------

The :class:`pyvista.DataSetFilters` is inherited by :class:`pyvista.Common` making
all the the following filters available as callable methods directly from any
PyVista dataset.


.. rubric:: Methods

.. autoautosummary:: pyvista.DataSetFilters
   :methods:


.. autoclass:: pyvista.DataSetFilters
   :members:
   :undoc-members:
